@@ -93,6 +93,23 @@ class References(ViewletBase):
 	resultNoRepeated = self.uniq(results)
         return resultNoRepeated
 
+    def translateMonth(self, month):
+	if((self.request['LANGUAGE'])[:2] == 'en'):
+	    return month
+	elif ((self.request['LANGUAGE'])[:2] == 'es'):
+	    if month == "Jan":
+		return "Ene"
+	    elif month == "Apr":
+		return "Abr"
+	    elif month == "Aug":
+		return "Ago"
+	    elif month == "Dec":
+		return "Dic"
+	    else:
+		return month
+	else:
+	    return month
+
     def getWorkRelatedPeople(self, work):
 	result = []
 	if work.portal_type == 'Work':
